
function project1D(allProj, spikeProj, binSz, col1, col2, mx, fs, colbg);

%% 1D projection of raw and spike-triggered stimuli, and 1D nonlinearity
%% allProj: response of filter to raw stimuli
%% spikeProj: response of filter to spike-triggered stimuli

if (exist('binSz') ~= 1)
   binSz = 8/25;
end
if (exist('col1') ~= 1)  % raw stimuli
   col1 = 'b';
end
if (exist('col2') ~= 1)  % spike-triggered stimuli
   col2 = 'r';
end
if (exist('mx') ~= 1)
   mx = 4;
end
if (exist('fs') ~= 1)
   fs = 14;
end
if (exist('colbg') ~= 1)
   colbg = 0.6*[1 1 1];
end

subplot(2,1,1);
[bH,bX] = histo(allProj,-binSz,0);
bH=bH/sum(bH);
binSz=mean(diff(bX));
sH = hist(spikeProj, bX);
sH = sH/sum(sH);
X = vectify([1;1]*[bX(1)-(bX(2)-bX(1))/2, bX+(bX(2)-bX(1))/2]);
plot(X,[0; vectify([1;1]*bH); 0], col1, 'LineWidth', 2);
hold on;
plot(X,[0; vectify([1;1]*sH); 0], col2, 'LineWidth', 2);
hold off
set(gca,'YLim',[0 1.1*max([bH,sH])]); set(gca,'XLim',[-mx mx]);
set(gca,'YTick', []);  set(gca, 'Xtick',[])
ylabel('histogram','FontSize',fs);
set(gca,'Color',colbg);
legend('# stimuli','# spikes');

subplot(2,1,2);
nl = zeros(size(bH));
nl = sH ./ bH;
nl = nl / max(nl);
plot(bX,nl,'k.-', 'lineWidth',2, 'markerSize',16);
ylabel('firing rate','FontSize',fs);
xlabel('filter response','FontSize',fs);
set(gca,'YLim',[0 1.1*max(nl)]); set(gca,'XLim',[-mx mx]);
set(gca,'YTick', []);  set(gca, 'Xtick',[])
pos = get(gca,'Position'); set(gca,'Position',[pos(1) pos(2)+0.05 pos(3) pos(4)]);


