
function project2D(allProj, spikeProj, binSz, npts, rot, col1, col2, mx, fs, colbg);

%% 2D projection of raw and spike-triggered stimuli, and 2D nonlinearity
%% allProj: response of pair of filters to raw stimuli
%% spikeProj: response of pair of filters to spike-triggered stimuli

if (exist('npts') ~= 1)
   npts = min(10000,size(spikeProj,1));
end
if (exist('rot') ~= 1)
   rot = 0;
end
if (exist('binSz') ~= 1)
   binSz = 8/25;
end
if (exist('col1') ~= 1)  % raw stimuli
   col1 = 'b';
end
if (exist('col2') ~= 1)  % spike-triggered stimuli
   col2 = 'r';
end
if (exist('mx') ~= 1)
   mx = 4;
end
if (exist('fs') ~= 1)
   fs = 14;
end
if (exist('colbg') ~= 1)
   colbg = 0.6*[1 1 1];
end

%% set values
kX = 1; kY = 2;
sz1 = 9;  %% sizes of scatterplot points
sz2 = 15;
wht = 0.99*[1 1 1];  % this prints correctly as white!
crp = 0.87;
cont=0.1*[0.5 1 2 4]
nstim = size(allProj,1);

figure;
sub = round(nstim/npts);
nsd=2.9;  c=cos(rot); s=sin(rot);
angles=2*pi*[0:30]'/30;
data = allProj(1:sub:end, [kX,kY])*[c s; -s c];
spikeData= spikeProj(1:sub:end, [kX,kY])*[c s; -s c];
h1=plot(data(:,1), data(:,2), [col1 '.'],'markerSize',sz1);
hold;
h2=plot(spikeData(:,1), spikeData(:,2), [col2 '.'],'markerSize',sz2); hold off
hold off
set(gca,'Color',colbg);
axis([-mx mx -mx mx]); axis('square')
set(gca,'XTick',[]); set(gca,'YTick',[]);
xlabel('stimulus component 1','FontSize',fs);
ylabel('stimulus component 2','FontSize',fs);
set(h1,'color','k');  %set(h3,'color','k');
set(h2,'color',wht);  %set(h4,'color',wht);

% Nonlinearity of 2D projection onto a pair of axes:

figure;
[bH,bY,bX] = jhisto(allProj(:,kY),allProj(:,kX),-binSz,0);
binSzX=mean(diff(bX)); binSzY=mean(diff(bY));
[sH,sY,sX] = jhisto(spikeProj(:,kY),spikeProj(:,kX), -[binSzY,binSzX],[0,0]);
osY = find(abs(sY)<binSzY/2); osX = find(abs(sX)<binSzX/2);
obY = find(abs(bY)<binSzY/2); obX = find(abs(bX)<binSzX/2);
nl = zeros(1+2*max([osY-1,length(sY)-osY,obY-1,length(bY)-obY]), ...
    1+2*max([osX-1,length(sX)-osX,obX-1,length(bX)-obX]));
onY = (size(nl,1)+1)/2;  onX = (size(nl,2)+1)/2;
nlY = [-(onY-1):(onY-1)]*binSzY;  nlX = [-(onX-1):(onX-1)]*binSzX;
filt = binomialFilter(3);
nl(onY+[1:length(sY)]-osY, onX+[1:length(sX)]-osX) = ...
    corrDn(corrDn(sH,filt),filt');
nl(onY+[1:length(bY)]-obY, onX+[1:length(bX)]-obX) = ...
    nl(onY+[1:length(bY)]-obY, onX+[1:length(bX)]-obX) ./ ...
    (corrDn(corrDn(bH,filt),filt') + 0.01);
dsc = mkDisc(size(nl),mx*crp/binSzX,[onY,onX],2);
onl = nl.^0.8;
nl = nl.^0.8 .* (dsc);  %% GAMMA
foo = sort(nl(:));  tmx = mean(foo(end-3));
nl = min(nl + (1-dsc)*tmx,  tmx);
imagesc(nlX,nlY,nl); axis('equal'); axis('xy'); colormap('gray')
set(gca,'XLim',crp*[-mx mx]); set(gca,'YLim',crp*[-mx mx]);
set(gca,'YTick',[]); set(gca,'XTick',[]);
set(gca,'box','off');
% draw contours
onl = corrDn(corrDn(onl,filt),filt');
hold on; [c,h]=contour(nlX, nlY, onl, cont);  hold off;
set(h,'lineWidth',2); set(h,'edgecolor','r');
angles2 = pi*[0:9]/18;
for r=pi*[0:3]/2
   cc = mx*[1,1,crp*cos(angles2),0,0,1; 0,0,crp*sin(angles2),1,1,1];
   cc = [cos(r),sin(r);-sin(r),cos(r)] * cc;
   hold; fill(cc(1,:), cc(2,:),'w'); hold off
end
xlabel('stimulus component 1','FontSize',fs);
ylabel('stimulus component 2','FontSize',fs);


